# CheckM

[![version status](https://img.shields.io/pypi/v/checkm-genome.svg)](https://pypi.python.org/pypi/checkm-genome)

Please see the project home page for usage details and installation instructions:
https://github.com/Ecogenomics/CheckM/wiki

Note: we do not recommend installing CheckM from the master branch. This may be unstable. Please install an official release of CheckM or use pip.

Copyright © 2014 Donovan Parks, Connor Skennerton, Michael Imelfort. See LICENSE.txt for further details.
